@@ -73,7 +73,9 @@ MR AB AND M/S CD VAN DER HEIDEN-MACNAY
  MR AS & D.E. DE LA MARE
 ESTATE OF THE LATE AB LE FONTAIN
 BIG BROTHER & THE HOLDING COMPANY
+MR PAUL J KEATING
 MR TOM JONES
+EDWARD G WHITLAM
 JAMES BROWN
 MR AS SMI9TH
 prof a.s.d. genius
